@@ -1,9 +1,10 @@
 use futures::FutureExt;
 
-use crate::spawn::MockKitsuneP2pEventHandler;
+use crate::{spawn::MockKitsuneP2pEventHandler, NOISE};
 
 use super::*;
 use crate::fixt::*;
+use arbitrary::Arbitrary;
 use fixt::prelude::*;
 
 mod bloom;
@@ -18,8 +19,9 @@ impl ShardedGossipLocal {
         host: HostApi,
         inner: ShardedGossipLocalState,
     ) -> Self {
-        // TODO: randomize space
-        let space = Arc::new(KitsuneSpace::new([0; 36].to_vec()));
+        let mut u = arbitrary::Unstructured::new(&NOISE);
+        let space = KitsuneSpace::arbitrary(&mut u).unwrap();
+        let space = Arc::new(space);
         Self {
             gossip_type,
             tuning_params: Default::default(),
