@@ -141,7 +141,7 @@ async fn partial_missing_doesnt_finish() {
             round_map: maplit::hashmap! {
                 cert.clone() => RoundState {
                     remote_agent_list: vec![],
-                    common_arc_set: Arc::new(ArcInterval::Full.into()),
+                    common_arc_set: Arc::new(DhtArcSet::Full),
                     num_sent_ops_blooms: 1,
                     received_all_incoming_ops_blooms: true,
                     last_touch: Instant::now(),
@@ -189,7 +189,7 @@ async fn missing_ops_finishes() {
             round_map: maplit::hashmap! {
                 cert.clone() => RoundState {
                     remote_agent_list: vec![],
-                    common_arc_set: Arc::new(ArcInterval::Full.into()),
+                    common_arc_set: Arc::new(DhtArcSet::Full),
                     num_sent_ops_blooms: 1,
                     received_all_incoming_ops_blooms: true,
                     last_touch: Instant::now(),
@@ -238,7 +238,7 @@ async fn missing_ops_doesnt_finish_awaiting_bloom_responses() {
             round_map: maplit::hashmap! {
                 cert.clone() => RoundState {
                     remote_agent_list: vec![],
-                    common_arc_set: Arc::new(ArcInterval::Full.into()),
+                    common_arc_set: Arc::new(DhtArcSet::Full),
                     num_sent_ops_blooms: 1,
                     received_all_incoming_ops_blooms: false,
                     last_touch: Instant::now(),
@@ -287,7 +287,7 @@ async fn bloom_response_finishes() {
             round_map: maplit::hashmap! {
                 cert.clone() => RoundState {
                     remote_agent_list: vec![],
-                    common_arc_set: Arc::new(ArcInterval::Full.into()),
+                    common_arc_set: Arc::new(DhtArcSet::Full),
                     num_sent_ops_blooms: 0,
                     received_all_incoming_ops_blooms: false,
                     last_touch: Instant::now(),
@@ -336,7 +336,7 @@ async fn bloom_response_doesnt_finish_outstanding_incoming() {
             round_map: maplit::hashmap! {
                 cert.clone() => RoundState {
                     remote_agent_list: vec![],
-                    common_arc_set: Arc::new(ArcInterval::Full.into()),
+                    common_arc_set: Arc::new(DhtArcSet::Full),
                     num_sent_ops_blooms: 1,
                     received_all_incoming_ops_blooms: false,
                     last_touch: Instant::now(),
@@ -388,7 +388,7 @@ async fn no_data_still_finishes() {
             round_map: maplit::hashmap! {
                 bob_cert.clone() => RoundState {
                     remote_agent_list: vec![],
-                    common_arc_set: Arc::new(ArcInterval::Full.into()),
+                    common_arc_set: Arc::new(DhtArcSet::Full),
                     num_sent_ops_blooms: 0,
                     received_all_incoming_ops_blooms: false,
                     last_touch: Instant::now(),
@@ -411,7 +411,7 @@ async fn no_data_still_finishes() {
             round_map: maplit::hashmap! {
                 alice_cert.clone() => RoundState {
                     remote_agent_list: vec![],
-                    common_arc_set: Arc::new(ArcInterval::Full.into()),
+                    common_arc_set: Arc::new(DhtArcSet::Full),
                     num_sent_ops_blooms: 1,
                     received_all_incoming_ops_blooms: true,
                     last_touch: Instant::now(),
