@@ -24,10 +24,6 @@ pub enum KitsuneP2pError {
     #[error("Decoding Error: {0}")]
     DecodingError(Box<str>),
 
-    /// TransportError
-    #[error(transparent)]
-    TransportError(#[from] kitsune_p2p_types::transport::TransportError),
-
     /// std::io::Error
     #[error(transparent)]
     StdIoError(#[from] std::io::Error),
